@@ -1,9 +1,8 @@
 use strict;
 use warnings;
 package Device::Onkyo;
-$Device::Onkyo::VERSION = '1.142220';
+$Device::Onkyo::VERSION = '1.143250';
 use Carp qw/croak carp/;
-use Device::SerialPort qw/:PARAM :STAT 0.07/;
 use Fcntl;
 use IO::Select;
 use Socket;
@@ -84,6 +83,9 @@ sub _open_serial_port {
   $self->{type} = 'ISCP';
   my $dev = $self->{device};
   print STDERR "Opening $dev as serial port\n" if DEBUG;
+  eval { require Device::SerialPort; };
+  die "Device::SerialPort is required for serial port devices\n$@\n" if ($@);
+  import Device::SerialPort qw/:PARAM :STAT 0.07/;
   my $fh = gensym();
   my $sport = tie (*$fh, 'Device::SerialPort', $dev) or
     croak "Could not tie serial port, $dev, to file handle: $!";
@@ -388,7 +390,7 @@ Device::Onkyo - Perl module to control Onkyo/Integra AV equipment
 
 =head1 VERSION
 
-version 1.142220
+version 1.143250
 
 =head1 SYNOPSIS
 
